// Copyright (c) 2002 Rob Kaper <cap@capsi.com>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License version 2.1 as published by the Free Software Foundation.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this library; see the file COPYING.LIB.  If not, write to
// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.

#ifndef LIBCAPSI_NETWORK_SOCKET_H
#define LIBCAPSI_NETWORK_SOCKET_H

/* Most of this code was originally written by Erik van Zijst
 * <icehawk@prutser.cx> and taken from the KMonop development team with
 * permission. Rob Kaper <cap@capsi.com> then ported it from C to C++ and
 * turned it into a library for the RealFC project.
 */
     
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <unistd.h>  
#include <netinet/in.h>
#include <netdb.h>
#include <fcntl.h>
#include <arpa/inet.h>

#include <string>

#define	SOCKET_NEW	1
#define	SOCKET_OK	0
#define SOCKET_BYE	-1
#define	SOCKET_GONE	-2
/*
 * Class to handle incoming sockets. Can/will be used to store fd
 * information, etc etc.
 */

class Socket
{
	public:
		Socket(unsigned int _fd);
		virtual ~Socket();
		int ioWrite(std::string data);
		int io_accept();
		int io_data();
		void io_close(fd_set);

		void setFd(unsigned int _fd) { m_fd = _fd; }

		unsigned int fd() { return m_fd; }
        std::string fqdn() { return m_fqdn; }

		int status;
		int port; // whether we are a listenport socket

        std::string m_ipAddr, m_fqdn, ioBuf;
		Socket *next;
private:
	unsigned int m_fd;
};

extern Socket *s1;
extern Socket *sN;

#endif // LIBCAPSI_NETWORK_SOCKET_H
